@@ -2,12 +2,14 @@
 from .regularization import create_regularization
 from .model_effects import ModelEffects
 from .model_means import ModelMeans
-from .stats import gather_statistics
+from .stats import calc_stats, gather_statistics
 from .means import estimate_means
+from .plot import semplot
 from .model import Model
+from . import multigroup
 from . import examples
 from . import efa
 
 name = "semopy"
-__version__ = "2.0.8"
+__version__ = "2.0.11"
 __author__ = "Georgy Meshcheryakov"
